==> nomachine-7.8.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXWebInfoFilesControl.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXWebInfoFilesControl;no warnings;($serviceMonitoringDelay=3600);(
$serviceStatus=(0x1552+ 3425-0x22b3));($lastCheckTime=(0x10d4+ 1803-0x17df));(
$infoFilesDirectory=(((((($GLOBAL::VAR_ROOT.$GLOBAL::DIRECTORY_SLASH).
"\x74\x6d\x70").$GLOBAL::DIRECTORY_SLASH).
"\x6e\x78\x77\x65\x62\x70\x6c\x61\x79\x65\x72").$GLOBAL::DIRECTORY_SLASH).
"\x69\x6e\x66\x6f"));sub BEGIN{require warnings;do{
"\x77\x61\x72\x6e\x69\x6e\x67\x73"->import};}sub enableService{if ((
isServiceEnabled ()!=(0x013f+ 4590-0x132c))){init ();}($serviceStatus=
(0x1530+ 2874-0x2069));return;}sub disableService{if ((isServiceEnabled ()==
(0x1254+ 807-0x157a))){deleteAllInfoFiles ();}($serviceStatus=
(0x06c0+ 7754-0x250a));return;}sub isServiceEnabled{return ($serviceStatus);}sub
 init{($lastCheckTime=Common::NXTime::getSecondsSinceEpoch ());return;}sub 
__checkIsTimeForRemoveInfoFiles{(my $currentTime=
Common::NXTime::getSecondsSinceEpoch ());(my $delay=$serviceMonitoringDelay);if 
((($lastCheckTime+$delay)<=$currentTime)){($lastCheckTime=$currentTime);return (
(0x2561+ 105-0x25c9));}return ((0x0798+ 4284-0x1854));}sub checkService{if ((
isServiceEnabled ()!=(0x23b7+ 605-0x2613))){return ((0x1d2c+ 1688-0x23c3));}if (
(__checkIsTimeForRemoveInfoFiles ()==(0x0709+ 1099-0x0b54))){return (
(0x114b+ 4411-0x2285));}if ((not (Common::NXFile::directoryExists (
$infoFilesDirectory)))){(my $errorString=libnxh::NXGetErrorString ());(my $errorNumber
=libnxh::NXGetError ());Logger::debug (((((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x63\x68\x65\x63\x6b\x53\x65\x72\x76\x69\x63\x65\x20\x4d\x69\x73\x73\x69\x6e\x67\x20\x64\x69\x72\x65\x63\x74\x6f\x72\x79\x3a\x20\x27"
.$infoFilesDirectory)."\x27\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20").
$errorNumber)."\x2c\x20").$errorString)."\x2e"));return;}(my $list=
libnxhs::NXGetFilesList ($infoFilesDirectory));if (($list eq (""))){
Logger::debug (((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x63\x68\x65\x63\x6b\x53\x65\x72\x76\x69\x63\x65\x20\x44\x69\x72\x65\x63\x74\x6f\x72\x79\x3a\x20\x27"
.$infoFilesDirectory)."\x27\x20\x69\x73\x20\x65\x6d\x70\x74\x79\x2e"));return;}
foreach my $name (split ( /\n/ ,$list,(0x0b70+ 3246-0x181e))){if (($name=~ /^[\d\w]{32}\.info$/ )
){(my $path=(($infoFilesDirectory.$GLOBAL::DIRECTORY_SLASH).$name));(my $fileCTime
=Common::NXCore::NXFileCTime ($path));if ((checkAndRemoveInfoFile ($fileCTime)==
(0x06b8+ 4566-0x188d))){deleteInfoFile ($name);}}}return;}sub 
checkAndRemoveInfoFile{(my $cTime=(shift (@_)||(0x0f0b+ 836-0x124f)));if ((
$cTime<=(0x10e8+ 380-0x1264))){return;}if ((($cTime+$serviceMonitoringDelay)<
Common::NXTime::getSecondsSinceEpoch ())){return ((0x0b79+ 5985-0x22d9));}
Logger::debug2 (
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x63\x68\x65\x63\x6b\x41\x6e\x64\x52\x65\x6d\x6f\x76\x65\x49\x6e\x66\x6f\x46\x69\x6c\x65\x20\x46\x69\x6c\x65\x20\x6e\x6f\x74\x20\x72\x65\x61\x64\x79\x20\x74\x6f\x20\x72\x65\x6d\x6f\x76\x65\x2e"
);return ((0x06b2+ 674-0x0954));}sub deleteAllInfoFiles{Logger::debug2 (
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x64\x65\x6c\x65\x74\x65\x41\x6c\x6c\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x28\x29\x20\x63\x61\x6c\x6c\x65\x64\x2e"
);if ((not (Common::NXFile::directoryExists ($infoFilesDirectory)))){(my $errorString
=libnxh::NXGetErrorString ());(my $errorNumber=libnxh::NXGetError ());
Logger::debug (((((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x64\x65\x6c\x65\x74\x65\x41\x6c\x6c\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x3a\x20\x4d\x69\x73\x73\x69\x6e\x67\x20\x64\x69\x72\x65\x63\x74\x6f\x72\x79\x3a\x20\x27"
.$infoFilesDirectory)."\x27\x2e\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20").
$errorNumber)."\x2c\x20").$errorString)."\x2e"));return;}(my $list=
libnxhs::NXGetFilesList ($infoFilesDirectory));if (($list eq (""))){
Logger::debug (((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x64\x65\x6c\x65\x74\x65\x41\x6c\x6c\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x3a\x20\x44\x69\x72\x65\x63\x74\x6f\x72\x79\x3a\x20\x27"
.$infoFilesDirectory)."\x27\x20\x69\x73\x20\x65\x6d\x70\x74\x79\x2e"));}foreach my $name
 (split ( /\n/ ,$list,(0x0144+ 6485-0x1a99))){deleteInfoFile ($name);}return;}
sub deleteInfoFile{(my $filename=(shift (@_)||("")));Logger::debug2 (((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x64\x65\x6c\x65\x74\x65\x49\x6e\x66\x6f\x46\x69\x6c\x65\x28"
.$filename)."\x29\x20\x63\x61\x6c\x6c\x65\x64\x2e"));if (($filename=~ /^[\d\w]{32}\.info$/ )
){(my $path=(($infoFilesDirectory.$GLOBAL::DIRECTORY_SLASH).$filename));if ((
libnxh::NXFileExists ($path)==(0x03e7+ 381-0x0563))){if ((libnxh::NXFileRemove (
$path)!=(0x19b5+ 600-0x1c0d))){(my $errorString=libnxh::NXGetErrorString ());(my $errorNumber
=libnxh::NXGetError ());Logger::warning (((((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6d\x6f\x76\x65\x20\x66\x69\x6c\x65\x20\x27"
.$path)."\x27\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20").$errorNumber).
"\x2c\x20").$errorString)."\x2e"));}else{Logger::debug (((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x20\x46\x69\x6c\x65\x20\x27"
.$path)."\x27\x20\x72\x65\x6d\x6f\x76\x65\x64\x2e"));}}else{(my $errorString=
libnxh::NXGetErrorString ());(my $errorNumber=libnxh::NXGetError ());
Logger::debug2 (((((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x20\x46\x69\x6c\x65\x20\x27"
.$path).
"\x27\x20\x64\x6f\x65\x73\x6e\x74\x20\x65\x78\x69\x73\x74\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20"
).$errorNumber)."\x2c\x20").$errorString)."\x2e"));}}return;}sub 
setInfoDirectoryPermissionByAdmin{Logger::debug (
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x73\x65\x74\x49\x6e\x66\x6f\x44\x69\x72\x65\x63\x74\x6f\x72\x79\x50\x65\x72\x6d\x69\x73\x73\x69\x6f\x6e\x42\x79\x41\x64\x6d\x69\x6e\x28\x29\x20\x63\x61\x6c\x6c\x65\x64\x2e"
);main::nxrequire (
"\x4e\x58\x53\x79\x73\x74\x65\x6d\x44\x61\x65\x6d\x6f\x6e\x73");if ((not (
NXSystemDaemons::isHttpdEnabledInLicenceAndConfig ()))){return;}if ((not (
main::effectiveUserIsAdministrator ()))){return;}if ((not (
Common::NXFile::directoryExists ($infoFilesDirectory)))){my ($errorMsg);if ((not
 (Common::NXPaths::makePath ((\$errorMsg),$infoFilesDirectory)))){
Logger::warning (((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x63\x72\x65\x61\x74\x65\x20\x64\x69\x72\x65\x63\x74\x6f\x72\x79\x20"
.$infoFilesDirectory)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$errorMsg)
."\x2e"));return ((0x11d4+ 2079-0x19f2));}}my ($errorNumber);my ($errorString);(my $silent
=(0x0be1+ 6496-0x2540));(my $permissions=((($NXBits::UserReadWrite+
$NXBits::UserExecute)+$NXBits::GroupReadWrite)+$NXBits::GroupExecute));if ((
Common::NXFile::setPermissions_unix ($infoFilesDirectory,$permissions,(
\$errorNumber),(\$errorString),$silent)==(-(0x022d+ 1868-0x0978)))){
Logger::debug (((((((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x63\x68\x61\x6e\x67\x65\x20\x61\x63\x63\x65\x73\x73\x20\x72\x69\x67\x68\x74\x73\x3a\x20"
.$infoFilesDirectory)."\x20\x74\x6f\x20").$permissions).
"\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$errorNumber)."\x2c\x20").
$errorString)."\x2e"));}(my $ApacheUname=(""));if (($GLOBAL::ApacheUname ne ("")
)){($ApacheUname=$GLOBAL::ApacheUname);}else{(my (@htdUsers)=
NXTools::getNXHtdUser ());($ApacheUname=$htdUsers[(0x0da8+ 4810-0x2072)]);}(my $uid
=Common::NXCore::userInfoGetUidByUsername ($ApacheUname));(my $gid=
Common::NXCore::userInfoGetGidByUsername ("\x6e\x78"));if ((
Common::NXFile::setOwnershipForUser_unix ($infoFilesDirectory,$uid,$gid,(
\$errorString),(\$errorNumber),$silen)==(-(0x16ca+ 580-0x190d)))){Logger::debug 
(((((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x63\x68\x61\x6e\x67\x65\x20\x6f\x77\x6e\x65\x72\x20\x6f\x66\x20"
.$infoFilesDirectory)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").
$errorNumber)."\x2c\x20").$errorString)."\x2e"));}return;}"\x3f\x3f\x3f";

==> nomachine-7.9.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXWebInfoFilesControl.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXWebInfoFilesControl;no warnings;($serviceMonitoringDelay=
(0x11b8+ 4624-0x15b8));($serviceStatus=(0x1174+ 458-0x133e));($lastCheckTime=
(0x0f93+ 2009-0x176c));($infoFilesDirectory=(((((($GLOBAL::VAR_ROOT.
$GLOBAL::DIRECTORY_SLASH)."\x74\x6d\x70").$GLOBAL::DIRECTORY_SLASH).
"\x6e\x78\x77\x65\x62\x70\x6c\x61\x79\x65\x72").$GLOBAL::DIRECTORY_SLASH).
"\x69\x6e\x66\x6f"));sub BEGIN{require warnings;do{
"\x77\x61\x72\x6e\x69\x6e\x67\x73"->import};}sub enableService{if ((
isServiceEnabled ()!=(0x0719+ 4472-0x1890))){init ();}($serviceStatus=
(0x16d5+ 2166-0x1f4a));return;}sub disableService{if ((isServiceEnabled ()==
(0x0938+ 2497-0x12f8))){deleteAllInfoFiles ();}($serviceStatus=
(0x1858+ 2743-0x230f));return;}sub isServiceEnabled{return ($serviceStatus);}sub
 init{($lastCheckTime=Common::NXTime::getSecondsSinceEpoch ());return;}sub 
__checkIsTimeForRemoveInfoFiles{(my $currentTime=
Common::NXTime::getSecondsSinceEpoch ());(my $delay=$serviceMonitoringDelay);if 
((($lastCheckTime+$delay)<=$currentTime)){($lastCheckTime=$currentTime);return (
(0x16bd+ 991-0x1a9b));}return ((0x1c4b+ 1574-0x2271));}sub checkService{if ((
isServiceEnabled ()!=(0x112b+ 4748-0x23b6))){return ((0x05f4+ 3337-0x12fc));}if 
((__checkIsTimeForRemoveInfoFiles ()==(0x0d99+ 6093-0x2566))){return (
(0x0c37+ 3712-0x1ab6));}if ((not (Common::NXFile::directoryExists (
$infoFilesDirectory)))){(my $errorString=libnxh::NXGetErrorString ());(my $errorNumber
=libnxh::NXGetError ());Logger::debug (((((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x63\x68\x65\x63\x6b\x53\x65\x72\x76\x69\x63\x65\x20\x4d\x69\x73\x73\x69\x6e\x67\x20\x64\x69\x72\x65\x63\x74\x6f\x72\x79\x3a\x20\x27"
.$infoFilesDirectory)."\x27\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20").
$errorNumber)."\x2c\x20").$errorString)."\x2e"));return;}(my $list=
libnxhs::NXGetFilesList ($infoFilesDirectory));if (($list eq (""))){
Logger::debug (((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x63\x68\x65\x63\x6b\x53\x65\x72\x76\x69\x63\x65\x20\x44\x69\x72\x65\x63\x74\x6f\x72\x79\x3a\x20\x27"
.$infoFilesDirectory)."\x27\x20\x69\x73\x20\x65\x6d\x70\x74\x79\x2e"));return;}
foreach my $name (split ( /\n/ ,$list,(0x121d+ 3395-0x1f60))){if (($name=~ /^[\d\w]{32}\.info$/ )
){(my $path=(($infoFilesDirectory.$GLOBAL::DIRECTORY_SLASH).$name));(my $fileCTime
=Common::NXCore::NXFileCTime ($path));if ((checkAndRemoveInfoFile ($fileCTime)==
(0x1597+ 1753-0x1c6f))){deleteInfoFile ($name);}}}return;}sub 
checkAndRemoveInfoFile{(my $cTime=(shift (@_)||(0x119d+ 2014-0x197b)));if ((
$cTime<=(0x0162+ 7233-0x1da3))){return;}if ((($cTime+$serviceMonitoringDelay)<
Common::NXTime::getSecondsSinceEpoch ())){return ((0x0202+ 792-0x0519));}
Logger::debug2 (
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x63\x68\x65\x63\x6b\x41\x6e\x64\x52\x65\x6d\x6f\x76\x65\x49\x6e\x66\x6f\x46\x69\x6c\x65\x20\x46\x69\x6c\x65\x20\x6e\x6f\x74\x20\x72\x65\x61\x64\x79\x20\x74\x6f\x20\x72\x65\x6d\x6f\x76\x65\x2e"
);return ((0x139d+ 275-0x14b0));}sub deleteAllInfoFiles{Logger::debug2 (
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x64\x65\x6c\x65\x74\x65\x41\x6c\x6c\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x28\x29\x20\x63\x61\x6c\x6c\x65\x64\x2e"
);if ((not (Common::NXFile::directoryExists ($infoFilesDirectory)))){(my $errorString
=libnxh::NXGetErrorString ());(my $errorNumber=libnxh::NXGetError ());
Logger::debug (((((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x64\x65\x6c\x65\x74\x65\x41\x6c\x6c\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x3a\x20\x4d\x69\x73\x73\x69\x6e\x67\x20\x64\x69\x72\x65\x63\x74\x6f\x72\x79\x3a\x20\x27"
.$infoFilesDirectory)."\x27\x2e\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20").
$errorNumber)."\x2c\x20").$errorString)."\x2e"));return;}(my $list=
libnxhs::NXGetFilesList ($infoFilesDirectory));if (($list eq (""))){
Logger::debug (((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x64\x65\x6c\x65\x74\x65\x41\x6c\x6c\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x3a\x20\x44\x69\x72\x65\x63\x74\x6f\x72\x79\x3a\x20\x27"
.$infoFilesDirectory)."\x27\x20\x69\x73\x20\x65\x6d\x70\x74\x79\x2e"));}foreach my $name
 (split ( /\n/ ,$list,(0x10d1+ 2338-0x19f3))){deleteInfoFile ($name);}return;}
sub deleteInfoFile{(my $filename=(shift (@_)||("")));Logger::debug2 (((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x64\x65\x6c\x65\x74\x65\x49\x6e\x66\x6f\x46\x69\x6c\x65\x28"
.$filename)."\x29\x20\x63\x61\x6c\x6c\x65\x64\x2e"));if (($filename=~ /^[\d\w]{32}\.info$/ )
){(my $path=(($infoFilesDirectory.$GLOBAL::DIRECTORY_SLASH).$filename));if ((
libnxh::NXFileExists ($path)==(0x0d07+ 1474-0x12c8))){if ((libnxh::NXFileRemove 
($path)!=(0x0ca5+ 6426-0x25bf))){(my $errorString=libnxh::NXGetErrorString ());(my $errorNumber
=libnxh::NXGetError ());Logger::warning (((((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6d\x6f\x76\x65\x20\x66\x69\x6c\x65\x20\x27"
.$path)."\x27\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20").$errorNumber).
"\x2c\x20").$errorString)."\x2e"));}else{Logger::debug (((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x20\x46\x69\x6c\x65\x20\x27"
.$path)."\x27\x20\x72\x65\x6d\x6f\x76\x65\x64\x2e"));}}else{(my $errorString=
libnxh::NXGetErrorString ());(my $errorNumber=libnxh::NXGetError ());
Logger::debug2 (((((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x20\x46\x69\x6c\x65\x20\x27"
.$path).
"\x27\x20\x64\x6f\x65\x73\x6e\x74\x20\x65\x78\x69\x73\x74\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20"
).$errorNumber)."\x2c\x20").$errorString)."\x2e"));}}return;}sub 
setInfoDirectoryPermissionByAdmin{Logger::debug (
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x73\x65\x74\x49\x6e\x66\x6f\x44\x69\x72\x65\x63\x74\x6f\x72\x79\x50\x65\x72\x6d\x69\x73\x73\x69\x6f\x6e\x42\x79\x41\x64\x6d\x69\x6e\x28\x29\x20\x63\x61\x6c\x6c\x65\x64\x2e"
);main::nxrequire (
"\x4e\x58\x53\x79\x73\x74\x65\x6d\x44\x61\x65\x6d\x6f\x6e\x73");if ((not (
NXSystemDaemons::isHttpdEnabledInLicenceAndConfig ()))){return;}if ((not (
main::effectiveUserIsAdministrator ()))){return;}if ((not (
Common::NXFile::directoryExists ($infoFilesDirectory)))){my ($errorMsg);if ((not
 (Common::NXPaths::makePath ((\$errorMsg),$infoFilesDirectory)))){
Logger::warning (((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x63\x72\x65\x61\x74\x65\x20\x64\x69\x72\x65\x63\x74\x6f\x72\x79\x20"
.$infoFilesDirectory)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$errorMsg)
."\x2e"));return ((0x133d+ 1223-0x1803));}}my ($errorNumber);my ($errorString);(my $silent
=(0x1b12+ 2673-0x2582));(my $permissions=((($NXBits::UserReadWrite+
$NXBits::UserExecute)+$NXBits::GroupReadWrite)+$NXBits::GroupExecute));if ((
Common::NXFile::setPermissions_unix ($infoFilesDirectory,$permissions,(
\$errorNumber),(\$errorString),$silent)==(-(0x0942+ 2124-0x118d)))){
Logger::debug (((((((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x63\x68\x61\x6e\x67\x65\x20\x61\x63\x63\x65\x73\x73\x20\x72\x69\x67\x68\x74\x73\x3a\x20"
.$infoFilesDirectory)."\x20\x74\x6f\x20").$permissions).
"\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$errorNumber)."\x2c\x20").
$errorString)."\x2e"));}(my $ApacheUname=(""));if (($GLOBAL::ApacheUname ne ("")
)){($ApacheUname=$GLOBAL::ApacheUname);}else{(my (@htdUsers)=
NXTools::getNXHtdUser ());($ApacheUname=$htdUsers[(0x09cd+ 1362-0x0f1f)]);}(my $uid
=Common::NXCore::userInfoGetUidByUsername ($ApacheUname));(my $gid=
Common::NXCore::userInfoGetGidByUsername ("\x6e\x78"));if ((
Common::NXFile::setOwnershipForUser_unix ($infoFilesDirectory,$uid,$gid,(
\$errorString),(\$errorNumber),$silen)==(-(0x1659+ 1578-0x1c82)))){Logger::debug
 (((((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x63\x68\x61\x6e\x67\x65\x20\x6f\x77\x6e\x65\x72\x20\x6f\x66\x20"
.$infoFilesDirectory)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").
$errorNumber)."\x2c\x20").$errorString)."\x2e"));}return;}"\x3f\x3f\x3f";
